Crate tokio_watchdog

Crate tokio_watchdog 

Docs are on the way. API is unstable, submit your ideas though Github issues. Otherwise see README for API excerpt and example.

Main struct is Watchdog.

Structs

Pet
Reset/restart the watchdog, so it don’t activate
Rearm
Result returned from a fired Watchdog.
Watchdog
The main struct. A wrapper over tokio_timer::Delay that has handles that can reset it periodically.