Docs are on the way. API is unstable, submit your ideas though Github issues. Otherwise see README for API excerpt and example.
Main struct is Watchdog.
Docs are on the way. API is unstable, submit your ideas though Github issues. Otherwise see README for API excerpt and example.
Main struct is Watchdog.